import React from 'react';
import PropTypes from 'prop-types';
import { Variant, Language } from './types';
export interface SyntaxProps {
    /**
     * The children to render inside Code. This is usually going to be a formatted code block or line.
     */
    children: string;
    /**
     * An additional CSS class applied to the root element
     */
    className?: string;
    /**
     * The language used for syntax highlighting.
     *
     * default: `'auto'`
     */
    language?: Language;
    /**
     * The variant for the syntax-highlighted block.
     *
     * default: `'light'`
     */
    variant?: Variant;
}
declare function Syntax({ children, language, className, variant, ...rest }: SyntaxProps & React.HTMLAttributes<HTMLElement>): JSX.Element;
declare namespace Syntax {
    var displayName: string;
    var propTypes: {
        children: PropTypes.Validator<string>;
        lang: PropTypes.Requireable<"auto" | "none" | "ruby" | "javascript" | "typescript" | "csp" | "cpp" | "go" | "java" | "perl" | "php" | "python" | "scala" | "swift" | "kotlin" | "bash" | "shell" | "sql" | "yaml" | "json" | "graphql">;
        className: PropTypes.Requireable<string>;
        variant: PropTypes.Requireable<"dark" | "light">;
    };
}
export default Syntax;
